==> coro-1.0.3-000.tar.gz: coro-1.0.3-000/test/test_in_parallel.py <==
# Copyright (c) 2002-2011 IronPort Systems and Cisco Systems
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""Unittests for coro.in_parallel."""

import coro
import coro_unittest
import unittest

class Test(unittest.TestCase):

    def test_timeout(self):
        """Test in_parallel with timeout (interrupted)."""
        def sleeper(num):
            coro.sleep_relative(5)
            return num

        self.assertRaises(coro.TimeoutError,
                          coro.with_timeout,
                          2,
                          coro.in_parallel,
                          [(sleeper, (1,)),
                           (sleeper, (2,)),
                              (sleeper, (3,)),
                           ]
                          )

        results = coro.with_timeout(7, coro.in_parallel,
                                    [(sleeper, (4,)),
                                     (sleeper, (5,)),
                                        (sleeper, (6,)),
                                     ]
                                    )
        self.assertEqual(results, [4, 5, 6])

if __name__ == '__main__':
    coro_unittest.run_tests()

==> coro-1.0.5.tar.gz: coro-1.0.5/test/test_in_parallel.py <==
# Copyright (c) 2002-2011 IronPort Systems and Cisco Systems
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""Unittests for coro.in_parallel."""

import coro
from coro.test import coro_unittest
import unittest

class Test(unittest.TestCase):

    def test_timeout(self):
        """Test in_parallel with timeout (interrupted)."""
        def sleeper(num):
            coro.sleep_relative(5)
            return num

        self.assertRaises(coro.TimeoutError,
                          coro.with_timeout,
                          2,
                          coro.in_parallel,
                          [(sleeper, (1,)),
                           (sleeper, (2,)),
                              (sleeper, (3,)),
                           ]
                          )

        results = coro.with_timeout(7, coro.in_parallel,
                                    [(sleeper, (4,)),
                                     (sleeper, (5,)),
                                        (sleeper, (6,)),
                                     ]
                                    )
        self.assertEqual(results, [4, 5, 6])

if __name__ == '__main__':
    coro_unittest.run_tests()
